from django import forms
from django.conf import settings
from django.utils.translation import ugettext, ugettext_lazy as _

from paginas.models import Page


class PageForm(forms.ModelForm):
    path = forms.RegexField(label=_('Path'), max_length=100, regex=r'^[-\w/\.~]+$',
        help_text = _("Example: '/about/contact/'. Make sure to have leading"
                      " and trailing slashes."),
        error_message = _("This value must contain only letters, numbers,"
                          " dots, underscores, dashes, slashes or tildes."))

    class Meta:
        model = Page

    def clean_path(self):
        path = self.cleaned_data['path']
        if not path.startswith('/'):
            raise forms.ValidationError(ugettext('Path is missing a leading slash.'))
        if (settings.APPEND_SLASH and
            'django.middleware.common.CommonMiddleware' in settings.MIDDLEWARE_CLASSES and
            not path.endswith('/')):
            raise forms.ValidationError(ugettext('Path is missing a trailing slash.'))
        return path

    def clean(self):
        path = self.cleaned_data.get('path', None)
        sites = self.cleaned_data.get('sites', None)

        same_path = Page.objects.filter(path=path)
        if self.instance.pk:
            same_path = same_path.exclude(pk=self.instance.pk)

        if same_path.filter(sites__in=sites).exists():
            for site in sites:
                if same_path.filter(sites=site).exists():
                    raise forms.ValidationError(
                        _('Page with path %(path)s already exists for site %(site)s' %
                          {'path': path, 'site': site}))

        return super(PageForm, self).clean()
