from django.conf import settings
from django.contrib.sites.models import Site
from django.db import models
from django.utils.translation import ugettext_lazy as _


class Page(models.Model):
    title = models.CharField(_('title'), max_length=256)
    path = models.CharField(
        _('path'),
        max_length=128,
        db_index=True,
        help_text=_('Relative URL. Example: <i>/contact/</i>.')
    )
    content = models.TextField(_('content'), blank=True)
    template_name = models.CharField(
        _('template name'),
        max_length=64,
        blank=True,
        help_text=_("Example: <i>paginas/contact.html</i>. If this isn't provided"
                    ", the system will use <i>paginas/default.html</i>.")
    )

    pub_date = models.DateTimeField(_('publication date'), auto_now_add=True)
    last_modified = models.DateTimeField(_('last modified'), auto_now=True)
    sites = models.ManyToManyField(Site, default=[settings.SITE_ID])

    # SEO
    description = models.CharField(_('description'), max_length=256, blank=True)
    keywords = models.CharField(
        _('keywords'),
        max_length=128,
        blank=True,
        help_text=_('Separated by commas.')
    )

    class Meta:
        verbose_name = _('page')
        verbose_name_plural = _('pages')
        ordering = ('path',)

    def __unicode__(self):
        return u'%s (%s)' % (self.path, self.title)

    def get_absolute_url(self):
        return self.path
